Skip to contents

Custom print method that displays the palette name followed by hex color codes with actual colors visible in the console.

Usage

# S3 method for class 'ltc'
print(x, ...)

Arguments

x

An ltc palette object

...

Additional arguments (currently unused)

Value

Invisibly returns the palette object