Custom print method that displays the palette name followed by hex color codes with actual colors visible in the console.
Usage
# S3 method for class 'ltc'
print(x, ...)Custom print method that displays the palette name followed by hex color codes with actual colors visible in the console.
# S3 method for class 'ltc'
print(x, ...)